==============
 Specification
==============

The following is a high-level description of the CADF specification. The basic
component of the CADF spec are Events. The full CADF specification document
can be found here_.

.. _here: http://www.dmtf.org/standards/cadf

.. toctree::
   :maxdepth: 2

   events
   attachments
   credentials
   endpoints
   geolocations
   hosts
   identifiers
   measurements
   paths
   reasons
   reportersteps
   resources
   tags
   timestamps
   taxonomy
